@@ -1,16 +1,15 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "orgit-forge" "1.1.1"
+(define-package "orgit-forge" "20251101.2141"
   "Org links to Forge issue buffers."
-  '((emacs    "29.1")
-    (compat   "30.1")
-    (cond-let "0.2")
-    (forge    "0.6")
-    (magit    "4.5")
-    (org      "9.7")
-    (orgit    "2.1"))
+  '((emacs  "29.1")
+    (compat "30.1")
+    (forge  "0.6")
+    (magit  "4.4")
+    (org    "9.7")
+    (orgit  "2.1"))
   :url "https://github.com/magit/orgit-forge"
-  :commit "c2116b8701498bd11d8674065a5429d844985e46"
-  :revdesc "v1.1.1-0-gc2116b870149"
+  :commit "964a81d1e4e95a61e6304237172889b222fca845"
+  :revdesc "964a81d1e4e9"
   :keywords '("hypermedia" "vc")
   :authors '(("Jonas Bernoulli" . "emacs.orgit-forge@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.orgit-forge@jonas.bernoulli.dev")))
