@@ -1,21 +1,20 @@
 ;;; orgit-forge.el --- Org links to Forge issue buffers  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2020-2026 The Magit Project Contributors
+;; Copyright (C) 2020-2025 The Magit Project Contributors
 
 ;; Author: Jonas Bernoulli <emacs.orgit-forge@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/magit/orgit-forge
 ;; Keywords: hypermedia vc
 
-;; Package-Version: 1.1.1
-;; Package-Revision: v1.1.1-0-gc2116b870149
+;; Package-Version: 20251101.2141
+;; Package-Revision: 964a81d1e4e9
 ;; Package-Requires: (
-;;     (emacs   "29.1")
-;;     (compat  "30.1")
-;;     (cond-let "0.2")
-;;     (forge    "0.6")
-;;     (magit    "4.5")
-;;     (org      "9.7")
-;;     (orgit    "2.1"))
+;;     (emacs  "29.1")
+;;     (compat "30.1")
+;;     (forge   "0.6")
+;;     (magit   "4.4")
+;;     (org     "9.7")
+;;     (orgit   "2.1"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -40,7 +39,6 @@
 ;;; Code:
 
 (require 'compat)
-(require 'cond-let)
 
 (require 'forge)
 (require 'orgit)
@@ -74,16 +72,17 @@ These two are preserved for backward compatibly:
 
 When the region selects a topic, then store a link to the
 Forge-Topic mode buffer for that topic."
-  (cond-let ((derived-mode-p 'forge-topic-mode)
-             (orgit-topic-store-1 forge-buffer-topic))
-            ((derived-mode-p 'forge-topic-list-mode)
-             (orgit-topic-store-1 (forge-get-topic (tabulated-list-get-id))))
-            ([_(derived-mode-p 'magit-mode)]
-             [sections (or (magit-region-sections 'issue)
-                           (magit-region-sections 'pullreq))]
+  (cond ((derived-mode-p 'forge-topic-mode)
+         (orgit-topic-store-1 forge-buffer-topic))
+        ((derived-mode-p 'magit-mode)
+         (and-let* ((sections (or (magit-region-sections 'issue)
+                                  (magit-region-sections 'pullreq))))
+           (progn ; Work around debbugs#31840.
              (dolist (section sections)
                (orgit-topic-store-1 (oref section value)))
              t)))
+        ((derived-mode-p 'forge-topic-list-mode)
+         (orgit-topic-store-1 (forge-get-topic (tabulated-list-get-id))))))
 
 (defun orgit-topic-store-1 (topic)
   (org-link-store-props
@@ -127,6 +126,5 @@ Forge-Topic mode buffer for that topic."
 (provide 'orgit-forge)
 ;; Local Variables:
 ;; indent-tabs-mode: nil
-;; lisp-indent-local-overrides: ((cond . 0) (interactive . 0))
 ;; End:
 ;;; orgit-forge.el ends here
